##Title: Expanded sensitivity analyses leading to comparisons between Rothermel and emprical modeling methods. Includes ANOVA, Levene's Test, RMSE, and figures.

##Authors: Charles D. Davis, G. Matt Davies

##Date Last Modified: 23 February 2022

#Library for rstudio functions
install.packages ("rstudioapi")
library (rstudioapi)

#Getting the path of your current open file
current_path <- rstudioapi::getActiveDocumentContext()$path 
setwd(dirname(current_path))
print(getwd())

#Install and Load in requisite libraries
install.packages ("lsmeans")
install.packages ("foreach")
install.packages ("iterators")
install.packages ("GA")
install.packages ("rainbow")
install.packages ("pcaPP")
install.packages ("fda")
install.packages ("zoo")
install.packages ("sde")
install.packages ("ftsa")
install.packages ("forecast")
install.packages ("Rothermel")
install.packages ("plyr")
install.packages("car")
install.packages ("Metrics")
install.packages ("tidyverse")

library (lsmeans)
library (foreach)
library (iterators)
library (GA)
library (rainbow)
library (pcaPP)
library (fda)
library (zoo)
library (sde)
library (ftsa)
library (forecast)
library (Rothermel)
library (plyr)
library(car)
library (Metrics)
library (tidyverse)
library (readxl)

#Read in relevant data
#data <- read.csv(file.choose(), header = TRUE)
data <- read_excel("2A.DataFMs.xlsx", sheet = "FuelModels")
data <- as.data.frame(data)

#!!! THIS IS THE ONLY CODE YOU NEED TO CHANGE !!! 
rowtick       <- c(1:3)  
moiststeps    <- 5
windsteps     <- 10
mstep.no      <- 10
wstep.no      <- 2
#!!!

lengtharray <- moiststeps*windsteps

#!!! TO RUN, SCROLL TO BOTTOM !!!

#Create user function to perform fire behavior calculations based on Rothermel and Experimental Models - Data propogated in Excel or R
reg.function   <- function(a, b, d, e, aa, bb) {
  
  h <- sum(a != 0)
  
  for (j in 1:h) {
    modeltype    <- (b[a[j], 2]) ##static versus dynamic fuel model 
    fuelload     <- c((b[a[j], 3]), (b[a[j], 4]), (b[a[j], 5]), (b[a[j], 6]), (b[a[j], 7])) ##loadings for each fuel parameter
    satovol      <- c((b[a[j], 8]), (b[a[j], 9]), (b[a[j], 10]), (b[a[j], 11]), (b[a[j], 12])) ##surface area to volume ratios for fuel parameters
    beddep       <- (b[a[j], 13]) ##bed depth for the overall fuel model, here as calluna height
    moistureext  <- (b[a[j], 14]) ##moisture of extinction for overall fuel model
    heatcontent  <- c((b[a[j], 15]), (b[a[j], 16]), (b[a[j], 17]), (b[a[j], 18]), (b[a[j], 19])) ##heat contents for each fuel parameter
    moisturecont <- c((b[a[j], 20]), (b[a[j], 21]), (b[a[j], 22]), (b[a[j], 23]), (b[a[j], 24])) ##moisture contents for each fuel parameter
    windspeed    <- (b[a[j], 25]) ##windspeeds for overall fuel model
    slope        <- (b[a[j], 26]) ##constant 0 slope for overall fuel model
    ##all below parameters are simply to initialize vectors
    roth        <- c()
    roth2       <- c()
    emp1        <- c()
    emp2        <- c()
    emp3        <- c()
    rotha       <- c()
    roth2a      <- c()
    emp1a       <- c()
    emp2a       <- c()
    emp3a       <- c()
    rothm       <- c()
    roth2m      <- c()
    emp1m       <- c()
    emp2m       <- c()
    emp3m       <- c()
    mc          <- c()
    fm          <- c()
    mc.a        <- c()
    fm.a        <- c()
    mc.m        <- c()
    fm.m        <- c()
    mcn         <- c()
    mcn.a       <- c()
    mcn.m       <- c()
    ws          <- c()
    ws.a       <- c()
    ws.m       <- c()
    x1          <- c()
    y1          <- c()
    x1a         <- c()
    y1a         <- c()
    x1m         <- c()
    y1m         <- c()
    
    ##the top most nested loop runs for each fire risk scenario - high, moderate, and low
    for (i in 1:d) {
      ##this loop runs fire behaviour predictions for increasing windspeeds nested in the next loop running for each increase in FMC
      for (g in 1:e) {
        ##rate of spread prediction from Vacchiano and Ascoli (2015) R package
        R              <- ros(modeltype, fuelload, satovol, beddep, moistureext, heatcontent, moisturecont, windspeed, slope)
        ##some redundancy here for saving rate of spread to check the sensitivity function
        roth[g]        <- R[15] 
        roth2[g]       <- R[15]
        ##rate of spread prediction of Davies model 1 from Davies et al. (2009) - all emp1 are this model
        emp1[g]        <- 0.791 + 7.917*((beddep/100)^2)*(windspeed/3.6)
        ##rate of spread prediction of Davies model 2 from Davies et al. (2009) - all emp2 are this model
        emp2[g]        <- 8.304 + 7.286*((beddep/100)^2)*(windspeed/3.6) - 0.097*moisturecont[5]
        ##rate of spread prediction of Anderson equation 2 from Anderson et al. (2015) - all emp3 are this model
        emp3[g]        <- 6.421*((windspeed)^0.994)*((beddep/100)^0.372)*exp(-0.0761*moisturecont[1])*exp(-0.00313*moisturecont[5])
        ##moisture contents and fire risk scenario (1.high, 2.moderate, 3.low) save in final matrix
        mc[g]          <- i
        mcn[g]         <- moisturecont[5]
        fm[g]          <- a[j]
        ##some redundancy here to check the prediction outputs of the sensitivity function
        x1[g]          <- 0.791 + 7.917*((beddep/100)^2)*(windspeed/3.6)
        y1[g]          <- 8.304 + 7.286*((beddep/100)^2)*(windspeed/3.6) - 0.097*moisturecont[5]
        ##windspeeds saved to view in final matrix
        ws[g]          <- windspeed
        windspeed      <- windspeed + bb
      }
      ##setups for the function to save each parameter after runs in the inside loop; iterative and necessary to stack for unique changes in FMC and Windspeed
      emp1a <- as.list(emp1)
      emp2a <- as.list(emp2)
      emp3a <- as.list(emp3)
      x1a   <- as.list(x1)
      y1a   <- as.list(y1)
      rothm <- cbind(rothm, roth)
      roth2m<- cbind(roth2m, roth2)
      emp1m <- cbind(emp1m, emp1a)
      emp2m <- cbind(emp2m, emp2a)
      emp3m <- cbind(emp3m, emp3a)
      x1m   <- cbind(x1m, x1a)
      y1m   <- cbind(y1m, y1a)
      mc.a  <- as.list(mc)
      fm.a  <- as.list(fm)
      mc.m  <- cbind(mc.m, mc.a)
      fm.m  <- cbind(fm.m, fm.a)
      mcn.a <- as.list(mcn)
      mcn.m <- cbind(mcn.m, mcn.a)
      ws.a  <- as.list(ws)
      ws.m  <- cbind(ws.m, ws.a) 
      windspeed       <- (b[a[j], 25])
      moisturecont[5] <- moisturecont[5] + aa
    }
    ##unlisting each variable to save in the final matrix
    rothv   <- unlist(rothm)
    roth2v  <- unlist(roth2m)
    emp1v   <- unlist(emp1m)
    emp2v   <- unlist(emp2m)
    emp3v   <- unlist(emp3m)
    mc.v    <- unlist(mc.m)
    fm.v    <- unlist(fm.m)
    mcn.v   <- unlist(mcn.m)
    ws.v    <- unlist(ws.m)
    x1v     <- unlist(x1m)
    y1v     <- unlist(y1m)
    ##creation of the final matric so that the code does not need to be changed for changing names and that each regression matrix can be unique for unique fire risk scenarios
    regmat  <- matrix(c(rothv, emp1v, emp2v, emp3v, mc.v, fm.v, mcn.v, x1v, y1v, roth2v, ws.v), ncol = 11, dimnames = list(1:lengtharray, c("Rothermel", "Empirical Formula 1", "Empirical Formula 2", "Empirical Formula 3", "Moisture Content", "Fuel Model", "FM Name", "Mod 1 1:1", "Mod 2 1:1", "Roth 1:1", "Windspeed")))
    mats    <- paste("regmatrix.", a[j], sep = "")
    assign(mats, regmat, pos = .GlobalEnv)
    }
}

#Run function
reg.function(rowtick, data, moiststeps, windsteps, mstep.no, wstep.no)

##stack each fire risk scenario output
append <- rbind(regmatrix.1, regmatrix.2, regmatrix.3)

##Statistics Reformat Including Behave and FARSITE runs
ROSAOV <- read_excel("2B.SensitivityStatsFigs.xlsx", sheet = "ANOVA")
ROSAOV <- as.data.frame(ROSAOV)

##ANOVA, ROS is all rates of spread from all predictions, FuelModel is fire risk scenario (as fuel models in Legg et al., 2007)
predobs.aov <- aov(ROS~FuelModel*System, data = ROSAOV)

##ARE ASSUMPTIONS MET? NORMAL RESIDUALS (TOLERABLE)
qqnorm(residuals(predobs.aov))
qqline(residuals(predobs.aov))

##SUMMARY TO FIND SIGNIFICANCE
summary(predobs.aov)

##POST-HOC FOR SIG BETWEEN FUEL CLASSES($FuelModel) and FIRE PREDICTION SYSTEM ($System)
TukeyHSD(predobs.aov)

##CHECK IF DATA IS NORMAL
qqnorm(ROSAOV[, 1])
qqline(ROSAOV[, 1])

##LEVENE'S TEST FOR COMPAIRSON OF POPULATION VARIANCE FOR NON-NORMAL DATA

leveneTest(ROS~System*FuelModel, data = ROSAOV)

##REJECT OR ACCEPT THE NULL (REJECTED AS p < 2.2 e-16***)
##ACCEPT ALTERNATIVE HYPOTHESIS THAT AT LEAST TWO VARIANCES DIFFER

#read in appropriate data that includes all data in a different format
RMSEdat <- read_excel("2B.SensitivityStatsFigs.xlsx", sheet = "RMSE")
RMSEdat <- as.data.frame(RMSEdat)

##RMSE analytic comparisons for fire behaviour (rates of spread) between each prediction model
##roth is the R rothermel implementation, d1 is Davies 1, d2 is Davies 2, and is Anderson, beh is Behave, and far is FARSITE
##Behave - Andrews (2013), FARSITE - Finney (2004)
rmse.rothd1 <- rmse(RMSEdat[1:150, 7], RMSEdat[1:150, 4])
rmse.rothd2 <- rmse(RMSEdat[1:150, 8], RMSEdat[1:150, 4])
rmse.behd1 <- rmse(RMSEdat[1:150, 7], RMSEdat[1:150, 5])
rmse.behd2 <- rmse(RMSEdat[1:150, 8], RMSEdat[1:150, 5])
rmse.fard1 <- rmse(RMSEdat[1:150, 7], RMSEdat[1:150, 6])
rmse.fard2 <- rmse(RMSEdat[1:150, 8], RMSEdat[1:150, 6])
rmse.andd1 <- rmse(RMSEdat[1:150, 7], RMSEdat[1:150, 9])
rmse.andd2 <- rmse(RMSEdat[1:150, 8], RMSEdat[1:150, 9])

##For high risk only
rmse.rothd1.h <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 4])
rmse.rothd2.h <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 4])
rmse.behd1.h <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 5])
rmse.behd2.h <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 5])
rmse.fard1.h <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 6])
rmse.fard2.h <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 6])
rmse.andd1.h <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 9])
rmse.andd2.h <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 9])

##For moderate risk only
rmse.rothd1.m <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 4])
rmse.rothd2.m <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 4])
rmse.behd1.m <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 5])
rmse.behd2.m <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 5])
rmse.fard1.m <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 6])
rmse.fard2.m <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 6])
rmse.andd1.m <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 9])
rmse.andd2.m <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 9])

##For low risk only
rmse.rothd1.l <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 4])
rmse.rothd2.l <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 4])
rmse.behd1.l <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 5])
rmse.behd2.l <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 5])
rmse.fard1.l <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 6])
rmse.fard2.l <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 6])
rmse.andd1.l <- rmse(RMSEdat[1:50, 7], RMSEdat[1:50, 9])
rmse.andd2.l <- rmse(RMSEdat[1:50, 8], RMSEdat[1:50, 9])

#READ IN APPROPRIATE DATA
datamoist <- read_excel("2B.SensitivityStatsFigs.xlsx", sheet = "FacetMoist")
datamoist <- as.data.frame(datamoist)

dataws <- read_excel("2B.SensitivityStatsFigs.xlsx", sheet = "FacetWind")
dataws <- as.data.frame(dataws)

##SET VARIABLES FOR ANALYSES
moistLQ <- datamoist[31:45, 1:9]
moistUQ <- datamoist[106:120, 1:9]
wsLQ <- dataws[121:150, 1:9]
wsUQ <- dataws[1:30, 1:9]

##SET EXPRESSIONS TO ANNOTATE PLOTS
y <- expression("Rate of Spread ( m" ~ min^-1~")")

fc.h <- expression("High Fuel Class")

MLQ <- expression("Lower Quartile Wind Speed ( 9 m" ~ s^-1~")")

WUQ <- expression("Maximum Live Woody FMC ( 95 % )")
  
MUQ <- expression("Upper Quartile Wind Speed ( 19 m" ~ s^-1~")")

WLQ <- expression("Minimum Live Woody FMC ( 55 % )")

##FACET PLOTS FOR QUARTILE AND CLASS ANALYSES BETWEEN FIRE BEHAVIOUR PREDICTION METHODS - PLEASE RUN TO ANALYZE
par(mfrow = c(2, 4), mai = c(0.4, 0.4, 0.1, 0.1), oma = c(6, 3, 1, 1))

plot(jitter(moistLQ[c(1, 4, 7, 10, 13), 3]), moistLQ[c(1, 4, 7, 10, 13), 9], pch = 21, cex = 1.5, cex.lab = 1.5, cex.axis = 1.5, cex.main = 1.5, col = "white", bg = "springgreen4", main = "", xlab = "", ylab = "", ylim = c(0, 28), xlim = c(50, 100), yaxt = 'n', xaxt = 'n')
axis(1, at = c(55, 65, 75, 85, 95), labels = c(55, 65, 75, 85, 95), cex.axis = 1.25)
axis(2, at = c(0, 5, 10, 15, 20, 25), labels = c(0, 5, 10, 15, 20, 25), cex.axis = 1.25)
legend("topleft", inset = c(-0.2, -0.09), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = MLQ)
legend("topleft", inset = c(-0.2, 0.02), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = fc.h)

points(jitter(moistLQ[c(1, 4, 7, 10, 13), 3]), moistLQ[c(1, 4, 7, 10, 13), 4], pch = 21, cex = 1.5, col = "white", bg = "goldenrod")
#points(moistLQ[, 3], moistLQ[, 5], pch = c(21, 22, 23)[moistLQ[, 1]], cex = 1.5, col = "white", bg = "magenta3")
points(jitter(moistLQ[c(1, 4, 7, 10, 13), 3]), moistLQ[c(1, 4, 7, 10, 13), 6], pch = 21, cex = 1.5, col = "white", bg = "palevioletred")
#points(moistLQ[, 3], moistLQ[, 7], pch = c(21, 22, 23)[moistLQ[, 1]], cex = 1.5, col = "white", bg = "steelblue4")
points(jitter(moistLQ[c(1, 4, 7, 10, 13), 3]), moistLQ[c(1, 4, 7, 10, 13), 8], pch = 21, cex = 1.5, col = "white", bg = "skyblue2")

abline(lm(moistLQ[c(1, 4, 7, 10, 13), 4]~moistLQ[c(1, 4, 7, 10, 13), 3]), col = "goldenrod", lwd = 2, lty = 1)
#abline(lm(moistLQ[, 5]~moistLQ[, 3]), col = "magenta3", lwd = 2, lty = 1)
abline(lm(moistLQ[c(1, 4, 7, 10, 13), 6]~moistLQ[c(1, 4, 7, 10, 13), 3]), col = "palevioletred", lwd = 2, lty = 1)
#abline(lm(moistLQ[, 7]~moistLQ[, 3]), col = "steelblue4", lwd = 2, lty = 1)
abline(lm(moistLQ[c(1, 4, 7, 10, 13), 8]~moistLQ[c(1, 4, 7, 10, 13), 3]), col = "skyblue2", lwd = 2, lty = 1)
abline(lm(moistLQ[c(1, 4, 7, 10, 13), 9]~moistLQ[c(1, 4, 7, 10, 13), 3]), col = "springgreen4", lwd = 2, lty = 1)

plot(jitter(moistUQ[c(1, 4, 7, 10, 13), 3]), moistUQ[c(1, 4, 7, 10, 13), 9], pch = 21, cex = 1.5, cex.lab = 1.5, cex.axis = 1.5, cex.main = 1.5, col = "white", bg = "springgreen4", main = "", xlab = "", ylab = "", ylim = c(0, 28), xlim = c(50, 100), yaxt = 'n', xaxt = 'n')
axis(1, at = c(55, 65, 75, 85, 95), labels = c(55, 65, 75, 85, 95), cex.axis = 1.25)
axis(2, at = c(0, 5, 10, 15, 20, 25), labels = c(0, 5, 10, 15, 20, 25), cex.axis = 1.25)
legend("topleft", inset = c(-0.2, -0.09), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = MUQ)
legend("topleft", inset = c(-0.2, 0.02), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = fc.h)

points(jitter(moistUQ[c(1, 4, 7, 10, 13), 3]), moistUQ[c(1, 4, 7, 10, 13), 4], pch = 21, cex = 1.5, col = "white", bg = "goldenrod")
#points(jitter(moistUQ[c(1, 4, 7, 10, 13), 3]), moistUQ[c(1, 4, 7, 10, 13), 5], pch = c(21, 22, 23)[moistUQ[, 1]], cex = 1.5, col = "white", bg = "magenta3")
points(jitter(moistUQ[c(1, 4, 7, 10, 13), 3]), moistUQ[c(1, 4, 7, 10, 13), 6], pch = 21, cex = 1.5, col = "white", bg = "palevioletred")
#points(jitter(moistUQ[c(1, 4, 7, 10, 13), 3]), moistUQ[c(1, 4, 7, 10, 13), 7], pch = c(21, 22, 23)[moistUQ[, 1]], cex = 1.5, col = "white", bg = "steelblue4")
points(jitter(moistUQ[c(1, 4, 7, 10, 13), 3]), moistUQ[c(1, 4, 7, 10, 13), 8], pch = 21, cex = 1.5, col = "white", bg = "skyblue2")

abline(lm(moistUQ[c(1, 4, 7, 10, 13), 4]~moistUQ[c(1, 4, 7, 10, 13), 3]), col = "goldenrod", lwd = 2, lty = 1)
#abline(lm(moistUQ[c(1, 4, 7, 10, 13), 5]~moistUQ[c(1, 4, 7, 10, 13), 3]), col = "magenta3", lwd = 2, lty = 1)
abline(lm(moistUQ[c(1, 4, 7, 10, 13), 6]~moistUQ[c(1, 4, 7, 10, 13), 3]), col = "palevioletred", lwd = 2, lty = 1)
#abline(lm(moistUQ[c(1, 4, 7, 10, 13), 7]~moistUQ[c(1, 4, 7, 10, 13), 3]), col = "steelblue4", lwd = 2, lty = 1)
abline(lm(moistUQ[c(1, 4, 7, 10, 13), 8]~moistUQ[c(1, 4, 7, 10, 13), 3]), col = "skyblue2", lwd = 2, lty = 1)
abline(lm(moistUQ[c(1, 4, 7, 10, 13), 9]~moistUQ[c(1, 4, 7, 10, 13), 3]), col = "springgreen4", lwd = 2, lty = 1)

plot(jitter(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 9], pch = 21, cex = 1.5, cex.lab = 1.5, cex.axis = 1.5, cex.main = 1.5, col = "white", bg = "springgreen4", main = "", xlab = "", ylab = "", ylim = c(0, 28), xlim = c(3, 25), yaxt = 'n', xaxt = 'n')
axis(1, at = c(5, 11, 17, 23), labels = c(5, 11, 17, 23), cex.axis = 1.25)
axis(2, at = c(0, 5, 10, 15, 20, 25), labels = c(0, 5, 10, 15, 20, 25), cex.axis = 1.25)
legend("topleft", inset = c(-0.2, -0.06), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = WLQ)
legend("topleft", inset = c(-0.2, 0.02), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = fc.h)

points(jitter(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 4], pch = 21, cex = 1.5, col = "white", bg = "goldenrod")
#points(jitter(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 5], pch = 21, cex = 1.5, col = "white", bg = "magenta3")
points(jitter(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 6], pch = 21, cex = 1.5, col = "white", bg = "palevioletred")
#points(jitter(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 7], pch = 21, cex = 1.5, col = "white", bg = "steelblue4")
points(jitter(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 8], pch = 21, cex = 1.5, col = "white", bg = "skyblue2")

abline(lm(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 4]~wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "goldenrod", lwd = 2, lty = 1)
#abline(lm(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 5]~wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "magenta3", lwd = 2, lty = 1)
abline(lm(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 6]~wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "palevioletred", lwd = 2, lty = 1)
#abline(lm(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 7]~wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "steelblue4", lwd = 2, lty = 1)
abline(lm(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 8]~wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "skyblue2", lwd = 2, lty = 1)
abline(lm(wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 9]~wsLQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "springgreen4", lwd = 2, lty = 1)

plot(jitter(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 9], pch = 21, cex = 1.5, cex.lab = 1.5, cex.axis = 1.5, cex.main = 1.5, col = "white", bg = "springgreen4", main = "", xlab = "", ylab = "", ylim = c(0, 28), xlim = c(3, 25), yaxt = 'n', xaxt = 'n')
axis(1, at = c(5, 11, 17, 23), labels = c(5, 11, 17, 23), cex.axis = 1.25)
axis(2, at = c(0, 5, 10, 15, 20, 25), labels = c(0, 5, 10, 15, 20, 25), cex.axis = 1.25)
legend("topleft", inset = c(-0.2, -0.06), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = WUQ)
legend("topleft", inset = c(-0.2, 0.02), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = fc.h)

points(jitter(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 4], pch = 21, cex = 1.5, col = "white", bg = "goldenrod")
#points(jitter(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 5], pch = 21, cex = 1.5, col = "white", bg = "magenta3")
points(jitter(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 6], pch = 21, cex = 1.5, col = "white", bg = "palevioletred")
#points(jitter(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 7], pch = 21, cex = 1.5, col = "white", bg = "steelblue4")
points(jitter(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 8], pch = 21, cex = 1.5, col = "white", bg = "skyblue2")

abline(lm(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 4]~wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "goldenrod", lwd = 2, lty = 1)
#abline(lm(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 5]~wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "magenta3", lwd = 2, lty = 1)
abline(lm(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 6]~wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "palevioletred", lwd = 2, lty = 1)
#abline(lm(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 7]~wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "steelblue4", lwd = 2, lty = 1)
abline(lm(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 8]~wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "skyblue2", lwd = 2, lty = 1)
abline(lm(wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 9]~wsUQ[c(1, 4, 7, 10, 13, 16, 19, 22, 25, 28), 2]), col = "springgreen4", lwd = 2, lty = 1)

fc.l <- expression("Low Fuel Class")

plot(jitter(moistLQ[c(3, 6, 9, 12, 15), 3]), moistLQ[c(3, 6, 9, 12, 15), 9], pch = 21, cex = 1.5, cex.lab = 1.5, cex.axis = 1.5, cex.main = 1.5, col = "white", bg = "springgreen4", main = "", xlab = "", ylab = "", ylim = c(0, 28), xlim = c(50, 100), yaxt = 'n', xaxt = 'n')
axis(1, at = c(55, 65, 75, 85, 95), labels = c(55, 65, 75, 85, 95), cex.axis = 1.25)
axis(2, at = c(0, 5, 10, 15, 20, 25), labels = c(0, 5, 10, 15, 20, 25), cex.axis = 1.25)
legend("topleft", inset = c(-0.2, -0.09), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = MLQ)
legend("topleft", inset = c(-0.2, 0.02), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = fc.l)

points(jitter(moistLQ[c(3, 6, 9, 12, 15), 3]), moistLQ[c(3, 6, 9, 12, 15), 4], pch = 21, cex = 1.5, col = "white", bg = "goldenrod")
#points(moistLQ[, 3], moistLQ[, 5], pch = c(21, 22, 23)[moistLQ[, 1]], cex = 1.5, col = "white", bg = "magenta3")
points(jitter(moistLQ[c(3, 6, 9, 12, 15), 3]), moistLQ[c(3, 6, 9, 12, 15), 6], pch = 21, cex = 1.5, col = "white", bg = "palevioletred")
#points(moistLQ[, 3], moistLQ[, 7], pch = c(21, 22, 23)[moistLQ[, 1]], cex = 1.5, col = "white", bg = "steelblue4")
points(jitter(moistLQ[c(3, 6, 9, 12, 15), 3]), moistLQ[c(3, 6, 9, 12, 15), 8], pch = 21, cex = 1.5, col = "white", bg = "skyblue2")

abline(lm(moistLQ[c(3, 6, 9, 12, 15), 4]~moistLQ[c(3, 6, 9, 12, 15), 3]), col = "goldenrod", lwd = 2, lty = 1)
#abline(lm(moistLQ[, 5]~moistLQ[, 3]), col = "magenta3", lwd = 2, lty = 1)
abline(lm(moistLQ[c(3, 6, 9, 12, 15), 6]~moistLQ[c(3, 6, 9, 12, 15), 3]), col = "palevioletred", lwd = 2, lty = 1)
#abline(lm(moistLQ[, 7]~moistLQ[, 3]), col = "steelblue4", lwd = 2, lty = 1)
abline(lm(moistLQ[c(3, 6, 9, 12, 15), 8]~moistLQ[c(3, 6, 9, 12, 15), 3]), col = "skyblue2", lwd = 2, lty = 1)
abline(lm(moistLQ[c(3, 6, 9, 12, 15), 9]~moistLQ[c(3, 6, 9, 12, 15), 3]), col = "springgreen4", lwd = 2, lty = 1)

plot(jitter(moistUQ[c(3, 6, 9, 12, 15), 3]), moistUQ[c(3, 6, 9, 12, 15), 9], pch = 21, cex = 1.5, cex.lab = 1.5, cex.axis = 1.5, cex.main = 1.5, col = "white", bg = "springgreen4", main = "", xlab = "", ylab = "", ylim = c(0, 28), xlim = c(50, 100), yaxt = 'n', xaxt = 'n')
axis(1, at = c(55, 65, 75, 85, 95), labels = c(55, 65, 75, 85, 95), cex.axis = 1.25)
axis(2, at = c(0, 5, 10, 15, 20, 25), labels = c(0, 5, 10, 15, 20, 25), cex.axis = 1.25)
legend("topleft", inset = c(-0.2, -0.09), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = MUQ)
legend("topleft", inset = c(-0.2, 0.02), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = fc.l)

points(jitter(moistUQ[c(3, 6, 9, 12, 15), 3]), moistUQ[c(3, 6, 9, 12, 15), 4], pch = 21, cex = 1.5, col = "white", bg = "goldenrod")
#points(jitter(moistUQ[c(3, 6, 9, 12, 15), 3]), moistUQ[c(3, 6, 9, 12, 15), 5], pch = c(21, 22, 23)[moistUQ[, 1]], cex = 1.5, col = "white", bg = "magenta3")
points(jitter(moistUQ[c(3, 6, 9, 12, 15), 3]), moistUQ[c(3, 6, 9, 12, 15), 6], pch = 21, cex = 1.5, col = "white", bg = "palevioletred")
#points(jitter(moistUQ[c(3, 6, 9, 12, 15), 3]), moistUQ[c(3, 6, 9, 12, 15), 7], pch = c(21, 22, 23)[moistUQ[, 1]], cex = 1.5, col = "white", bg = "steelblue4")
points(jitter(moistUQ[c(3, 6, 9, 12, 15), 3]), moistUQ[c(3, 6, 9, 12, 15), 8], pch = 21, cex = 1.5, col = "white", bg = "skyblue2")

abline(lm(moistUQ[c(3, 6, 9, 12, 15), 4]~moistUQ[c(3, 6, 9, 12, 15), 3]), col = "goldenrod", lwd = 2, lty = 1)
#abline(lm(moistUQ[c(3, 6, 9, 12, 15), 5]~moistUQ[c(3, 6, 9, 12, 15), 3]), col = "magenta3", lwd = 2, lty = 1)
abline(lm(moistUQ[c(3, 6, 9, 12, 15), 6]~moistUQ[c(3, 6, 9, 12, 15), 3]), col = "palevioletred", lwd = 2, lty = 1)
#abline(lm(moistUQ[c(3, 6, 9, 12, 15), 7]~moistUQ[c(3, 6, 9, 12, 15), 3]), col = "steelblue4", lwd = 2, lty = 1)
abline(lm(moistUQ[c(3, 6, 9, 12, 15), 8]~moistUQ[c(3, 6, 9, 12, 15), 3]), col = "skyblue2", lwd = 2, lty = 1)
abline(lm(moistUQ[c(3, 6, 9, 12, 15), 9]~moistUQ[c(3, 6, 9, 12, 15), 3]), col = "springgreen4", lwd = 2, lty = 1)

plot(jitter(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 9], pch = 21, cex = 1.5, cex.lab = 1.5, cex.axis = 1.5, cex.main = 1.5, col = "white", bg = "springgreen4", main = "", xlab = "", ylab = "", ylim = c(0, 28), xlim = c(3, 25), yaxt = 'n', xaxt = 'n')
axis(1, at = c(5, 11, 17, 23), labels = c(5, 11, 17, 23), cex.axis = 1.25)
axis(2, at = c(0, 5, 10, 15, 20, 25), labels = c(0, 5, 10, 15, 20, 25), cex.axis = 1.25)
legend("topleft", inset = c(-0.2, -0.06), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = WLQ)
legend("topleft", inset = c(-0.2, 0.02), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = fc.l)

points(jitter(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 4], pch = 21, cex = 1.5, col = "white", bg = "goldenrod")
#points(jitter(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 5], pch = 21, cex = 1.5, col = "white", bg = "magenta3")
points(jitter(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 6], pch = 21, cex = 1.5, col = "white", bg = "palevioletred")
#points(jitter(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 7], pch = 21, cex = 1.5, col = "white", bg = "steelblue4")
points(jitter(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 8], pch = 21, cex = 1.5, col = "white", bg = "skyblue2")

abline(lm(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 4]~wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "goldenrod", lwd = 2, lty = 1)
#abline(lm(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 5]~wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "magenta3", lwd = 2, lty = 1)
abline(lm(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 6]~wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "palevioletred", lwd = 2, lty = 1)
#abline(lm(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 7]~wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "steelblue4", lwd = 2, lty = 1)
abline(lm(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 8]~wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "skyblue2", lwd = 2, lty = 1)
abline(lm(wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 9]~wsLQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "springgreen4", lwd = 2, lty = 1)

plot(jitter(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 9], pch = 21, cex = 1.5, cex.lab = 1.5, cex.axis = 1.5, cex.main = 1.5, col = "white", bg = "springgreen4", main = "", xlab = "", ylab = "", ylim = c(0, 28), xlim = c(3, 25), yaxt = 'n', xaxt = 'n')
axis(1, at = c(5, 11, 17, 23), labels = c(5, 11, 17, 23), cex.axis = 1.25)
axis(2, at = c(0, 5, 10, 15, 20, 25), labels = c(0, 5, 10, 15, 20, 25), cex.axis = 1.25)
legend("topleft", inset = c(-0.2, -0.06), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = WUQ)
legend("topleft", inset = c(-0.2, 0.02), xpd = TRUE, cex = 1, border = 0, bty = "n", legend = fc.l)

points(jitter(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 4], pch = 21, cex = 1.5, col = "white", bg = "goldenrod")
#points(jitter(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 5], pch = 21, cex = 1.5, col = "white", bg = "magenta3")
points(jitter(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 6], pch = 21, cex = 1.5, col = "white", bg = "palevioletred")
#points(jitter(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 7], pch = 21, cex = 1.5, col = "white", bg = "steelblue4")
points(jitter(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 8], pch = 21, cex = 1.5, col = "white", bg = "skyblue2")

abline(lm(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 4]~wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "goldenrod", lwd = 2, lty = 1)
#abline(lm(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 5]~wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "magenta3", lwd = 2, lty = 1)
abline(lm(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 6]~wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "palevioletred", lwd = 2, lty = 1)
#abline(lm(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 7]~wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "steelblue4", lwd = 2, lty = 1)
abline(lm(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 8]~wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "skyblue2", lwd = 2, lty = 1)
abline(lm(wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 9]~wsUQ[c(3, 6, 9, 12, 15, 18, 21, 24, 27, 30), 2]), col = "springgreen4", lwd = 2, lty = 1)

par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0), mar = c(0, 0, 0, 0), new = TRUE)

plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")

x <- expression("Wind Speed ( m" ~ s^-1~")")

text(-1.04, 0.19, labels = y, srt = 90, cex = 1.25)
text(-0.46, -0.84, labels = "Live Woody Moisture Content (%)", cex = 1.25)
text(0.57, -0.834, labels = x, cex = 1.25)
 
legend(-0.42, -.90, legend = c("Davies 2", "Anderson", "Roth", "Farsite"), col = c("skyblue2", "springgreen4", "goldenrod", "palevioletred"), bty = "n", lty = 1, y.intersp = 1.15, text.width = c(0.1, 0.1, 0.1, 0.09), lwd = 2, cex = 1.2, seg.len = 1.2, horiz = TRUE)

#References
#Anderson, W.R.; Cruz, M.G.; Fernandes, P.M.; McCaw, L.; Vega, J.A.; Bradstock, R.A.; Forgarty, L.; Gould, J.; McCarthy, G.; Marsden-Smedley, J.B.; Matthews, S.; Mattingley, G.; Pearce. H.G.; van Wilgen, B.W. A generic, empirical-based model for predicting rate of fire spread in shrublands. Int. J. Wildland Fire 2015, 24, 443-460. https://doi.org/10.1071/WF14130
#Andrews, P.L. Current status and future needs of the BehavePlus Fire Modeling System. Int. J. Wildland Fire 2013, 23, 21-33. https://doi.org/10.1071/WF12167
#Davies, G.M.; Legg, C.J.; Smith, A.A.; MacDonald, A.J. Rate of spread of fires in Calluna vulgaris-dominated moorlands. J. Appl. Ecol. 2009, 46, 1054-1063. https://doi.org/10.1111/j.1365-2664.2009.01681.x
#Finney, M.A. Farsite: Fire Area Simulator - Model Development and Evaluation; RMRS-RP-4; U.S. Department of Agriculture, Forest Service, Rocky Mountain Research Station: Fort Collins, CO, 2004. https://www.fs.usda.gov/treesearch/pubs/4617 (accessed 2019-10-2).
#Legg, C.J.; Davies, G.M.; Kitchen, K.; Marno, P. Developing a Fire Danger Rating System for Vegetation Fires in the UK: FireBeaters Phase I final report; Scottish Wildfire Forum, 2007. https://era.ed.ac.uk/handle/1842/3011 (accessed 2019-09-23).
#Vacchiano, G.; Ascoli, D. An Implementation of the Rothermel Fire Spread Model in the R Programming Language. Fire Technol. 2015a, 51, 523-535. https://doi.org/10.1007/s10694-014-0405-6
